Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nodejs/node.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorShigeki Ohtsu <ohtsu@iij.ad.jp>2015-04-23 09:25:15 +0300
committerShigeki Ohtsu <ohtsu@iij.ad.jp>2015-10-26 19:31:47 +0300
commit802a2e79e1adb22542ba12fba5e331e94277272d (patch)
tree601aa8947e9d78b0f9a912964738909ca40e086a /lib/tls.js
parentdf738ac56c31ac8a04d6afbd3d7be59cfa5c2e9a (diff)
tls, crypto: add ALPN Support
ALPN is added to tls according to RFC7301, which supersedes NPN. When the server receives both NPN and ALPN extensions from the client, ALPN takes precedence over NPN and the server does not send NPN extension to the client. alpnProtocol in TLSSocket always returns false when no selected protocol exists by ALPN. In https server, http/1.1 token is always set when no options.ALPNProtocols exists. PR-URL: https://github.com/nodejs/node/pull/2564 Reviewed-By: Fedor Indutny <fedor@indutny.com> Reviewed-By: Ben Noordhuis <info@bnoordhuis.nl>
Diffstat (limited to 'lib/tls.js')
-rw-r--r--lib/tls.js51
1 files changed, 33 insertions, 18 deletions
diff --git a/lib/tls.js b/lib/tls.js
index 0d85a948dcc..e269e800d31 100644
--- a/lib/tls.js
+++ b/lib/tls.js
@@ -33,27 +33,42 @@ exports.getCiphers = function() {
// Convert protocols array into valid OpenSSL protocols list
// ("\x06spdy/2\x08http/1.1\x08http/1.0")
-exports.convertNPNProtocols = function convertNPNProtocols(NPNProtocols, out) {
- // If NPNProtocols is Array - translate it into buffer
- if (Array.isArray(NPNProtocols)) {
- var buff = new Buffer(NPNProtocols.reduce(function(p, c) {
- return p + 1 + Buffer.byteLength(c);
- }, 0));
-
- NPNProtocols.reduce(function(offset, c) {
- var clen = Buffer.byteLength(c);
- buff[offset] = clen;
- buff.write(c, offset + 1);
-
- return offset + 1 + clen;
- }, 0);
-
- NPNProtocols = buff;
+function convertProtocols(protocols) {
+ var buff = new Buffer(protocols.reduce(function(p, c) {
+ return p + 1 + Buffer.byteLength(c);
+ }, 0));
+
+ protocols.reduce(function(offset, c) {
+ var clen = Buffer.byteLength(c);
+ buff[offset] = clen;
+ buff.write(c, offset + 1);
+
+ return offset + 1 + clen;
+ }, 0);
+
+ return buff;
+};
+
+exports.convertNPNProtocols = function(protocols, out) {
+ // If protocols is Array - translate it into buffer
+ if (Array.isArray(protocols)) {
+ protocols = convertProtocols(protocols);
}
+ // If it's already a Buffer - store it
+ if (protocols instanceof Buffer) {
+ out.NPNProtocols = protocols;
+ }
+};
+exports.convertALPNProtocols = function(protocols, out) {
+ // If protocols is Array - translate it into buffer
+ if (Array.isArray(protocols)) {
+ protocols = convertProtocols(protocols);
+ }
// If it's already a Buffer - store it
- if (NPNProtocols instanceof Buffer) {
- out.NPNProtocols = NPNProtocols;
+ if (protocols instanceof Buffer) {
+ // copy new buffer not to be modified by user
+ out.ALPNProtocols = new Buffer(protocols);
}
};